==> limix_plot-0.1.1.tar.gz: limix_plot-0.1.1/limix_plot/manhattan.py <==
from __future__ import division
import numpy as np
import matplotlib.pylab as plt
from itertools import cycle
from seaborn import color_palette
import logging

class ManhattanPlot(object):
    def __init__(self):
        self._logger = logging.getLogger(__file__)
        self._pv = dict()
        self._position = dict()
        self._chrom_size = dict()
        self._marker_names = dict()
        self._pinpoint = dict()
        self._pinpoint_prop = dict()
        self._pinpoint_show_name = dict()
        self._color_cycle = None
        self.significance_level = None

    def set_pv(self, chromid, pv):
        chromid = int(chromid)
        pv = np.asarray(pv, float).ravel()
        self._pv[chromid] = pv

    def set_marker_names(self, chromid, names):
        chromid = int(chromid)
        names = np.asarray(names)
        self._marker_names[chromid] = names

    # chromossome size (in number of bases)
    def set_size(self, chromid, size):
        chromid = int(chromid)
        size = np.asarray(size, int).ravel()
        self._chrom_size[chromid] = size

    # position (number of bases) within chromossome
    def set_position(self, chromid, pos):
        chromid = int(chromid)
        pos = np.asarray(pos, int).ravel()
        self._position[chromid] = pos

    def pinpoint(self, chromid, name, prop=None, show_name=True):
        if prop is None:
            prop = dict(color='red')

        if chromid not in self._pinpoint:
            self._pinpoint[chromid] = set()
            self._pinpoint_prop[chromid] = dict()
            self._pinpoint_show_name[chromid] = dict()

        self._pinpoint[chromid].add(name)
        self._pinpoint_prop[chromid][name] = prop
        self._pinpoint_show_name[chromid][name] = show_name

    def plot(self, axis=None):
        self._color_cycle = cycle(color_palette("colorblind", 23))
        axis = plt.gca() if axis is None else axis

        offset = 0
        chromids = self._pv.keys()
        for chromid in chromids:
            if chromid not in self._position:
                s = len(self._pv[chromid])
                self.set_position(chromid, np.arange(s))
                self.set_size(chromid, s)
            self._plot_points(offset + self._position[chromid],
                              self._pv[chromid], axis)
            if chromid not in self._chrom_size:
                estimated_size = (self._position[chromid][0]//2 +
                                  self._position[chromid][-1])
                self.set_size(chromid, estimated_size)
            offset += self._chrom_size[chromid]

        left = self._position.values()[0][0]
        ticks = []
        for chromid in chromids:
            right = left + self._chrom_size[chromid]
            ticks.append(left + (right-left)//2)
            left = right

        axis.set_xticks(ticks)
        axis.set_xticklabels(chromids)
        axis.set_xlim([0, offset])
        axis.set_xlabel('Chromossome')

        if self.significance_level is not None:
            axis.axhline(self.significance_level, color='red', lw=0.5)

        ylim = axis.get_ylim()
        if 0 < ylim[1]:
            axis.set_ylim(0., ylim[1])

        offset = 0
        for chromid in self._pinpoint.keys():
            for name in self._pinpoint[chromid]:
                coord = self._marker_coord(chromid, name)
                if coord is None:
                    continue
                if self._pinpoint_show_name[chromid][name]:
                    axis.annotate(name, (coord[0]+offset, coord[1]), fontsize=10, rotation=45, ha='left',
                                  va='bottom', fontweight='bold')
                prop = self._pinpoint_prop[chromid][name]
                axis.scatter(coord[0]+offset, coord[1], **prop)
            offset += self._chrom_size[chromid]

        return axis

    def _marker_coord(self, chromid, name):
        idxs = np.where(name == self._marker_names[chromid])[0]
        if len(idxs) < 1:
            self._logger.info('Could not find %s in marker names.', name)
            return None
        idx = idxs[0]
        x = self._position[chromid][idx]
        y = self._pv[chromid][idx]
        return (x, y)

    def _plot_points(self, pos, pv, axis):
        color = next(self._color_cycle)
        axis.scatter(pos, pv, color=color)


if __name__ == '__main__':
    np.random.seed(3463)
    pv1 = np.random.randn(100)
    pos1 = np.arange(100)
    pv2 = np.random.randn(50)
    pos2 = np.arange(50)

    mp = ManhattanPlot()
    mp.set_pv(1, -np.log10(pv1))
    mp.set_position(1, pos1)
    mp.set_size(1, 100)

    mp.set_pv(2, -np.log10(pv2))
    mp.set_position(2, pos2)
    mp.set_size(2, 50)
    ax = mp.plot()
    ax.set_ylabel(r'$-\log_{10}(P)$')
    plt.show()

==> limix_plot-1.0.1.tar.gz: limix_plot-1.0.1/limix_plot/manhattan.py <==
from __future__ import division
import numpy as np
import logging
from matplotlib.patches import Rectangle

class ManhattanPlot(object):
    def __init__(self, ax):
        self._ax = ax
        self._logger = logging.getLogger(__file__)
        self._pv = dict()
        self._position = dict()
        self._chrom_size = dict()
        self._marker_names = dict()
        self._pinpoint = dict()
        self._pinpoint_prop = dict()
        self._pinpoint_show_name = dict()
        self._color_cycle = None
        self.significance_level = None
        self.marker_size = 5.
        self._highlight_back = dict()

    def set_pv(self, chromid, pv):
        chromid = int(chromid)
        pv = np.asarray(pv, float).ravel()
        self._pv[chromid] = pv

    def set_marker_names(self, chromid, names):
        chromid = int(chromid)
        names = np.asarray(names)
        self._marker_names[chromid] = names

    # chromossome size (in number of bases)
    def set_size(self, chromid, size):
        chromid = int(chromid)
        size = np.asarray(size, int).ravel()
        self._chrom_size[chromid] = size

    # position (number of bases) within chromossome
    def set_position(self, chromid, pos):
        chromid = int(chromid)
        pos = np.asarray(pos, int).ravel()
        self._position[chromid] = pos

    def pinpoint(self, chromid, name, prop=None, show_name=True):
        if prop is None:
            prop = dict(color='red')

        if chromid not in self._pinpoint:
            self._pinpoint[chromid] = set()
            self._pinpoint_prop[chromid] = dict()
            self._pinpoint_show_name[chromid] = dict()

        self._pinpoint[chromid].add(name)
        self._pinpoint_prop[chromid][name] = prop
        self._pinpoint_show_name[chromid][name] = show_name

    def highlight_back(self, chromid, left_pos, right_pos):
        if chromid not in self._highlight_back:
            self._highlight_back[chromid] = []
        self._highlight_back[chromid].append((left_pos, right_pos))

    def plot(self):
        # self._color_cycle = cycle(color_palette("colorblind", 23))
        axis = self._ax

        offset = 0
        chromids = self._pv.keys()
        for chromid in chromids:
            if chromid not in self._position:
                s = len(self._pv[chromid])
                self.set_position(chromid, np.arange(s))
                self.set_size(chromid, s)
            self._plot_points(offset + self._position[chromid],
                              self._pv[chromid], axis)
            if chromid not in self._chrom_size:
                estimated_size = (self._position[chromid][0]//2 +
                                  self._position[chromid][-1])
                self.set_size(chromid, estimated_size)
            offset += self._chrom_size[chromid]

        left = self._position.values()[0][0]
        ticks = []
        for chromid in chromids:
            right = left + self._chrom_size[chromid]
            ticks.append(left + (right-left)//2)
            left = right

        axis.set_xticks(ticks)
        axis.set_xticklabels(chromids)
        axis.set_xlim([0, offset])
        axis.set_xlabel('Chromossome')

        if self.significance_level is not None:
            axis.axhline(self.significance_level, color='red', lw=0.5)

        ylim = axis.get_ylim()
        if 0 < ylim[1]:
            axis.set_ylim(0., ylim[1])

        offset = 0
        for chromid in chromids:
            if chromid in self._pinpoint:
                for name in self._pinpoint[chromid]:
                    coord = self._marker_coord(chromid, name)
                    if coord is None:
                        continue
                    if self._pinpoint_show_name[chromid][name]:
                        axis.annotate(name, (coord[0]+offset, coord[1]), fontsize=10, rotation=45, ha='left',
                                      va='bottom', fontweight='bold')
                    prop = self._pinpoint_prop[chromid][name]
                    axis.scatter(coord[0]+offset, coord[1], **prop)
            offset += self._chrom_size[chromid]

        offset = 0
        ymin, ymax = axis.get_ylim()
        for chromid in chromids:
            if chromid in self._highlight_back:
                for (left_pos, right_pos) in self._highlight_back[chromid]:
                    height = ymax - ymin
                    width = right_pos - left_pos
                    axis.add_patch(Rectangle((left_pos, ymin), width, height,
                                             facecolor='red',
                                             edgecolor='none',
                                             zorder=-500))
            offset += self._chrom_size[chromid]

        return axis

    def _marker_coord(self, chromid, name):
        idxs = np.where(name == self._marker_names[chromid])[0]
        if len(idxs) < 1:
            self._logger.info('Could not find %s in marker names.', name)
            return None
        idx = idxs[0]
        x = self._position[chromid][idx]
        y = self._pv[chromid][idx]
        return (x, y)

    def _plot_points(self, pos, pv, axis):
        # color = next(self._color_cycle)
        # axis.scatter(pos, pv, color=color, s=self.marker_size)
        axis.scatter(pos, pv, s=self.marker_size)
